/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.geronimo.gshell.whisper.transport;

import java.net.URI;

import org.codehaus.plexus.PlexusContainer;
import org.codehaus.plexus.component.annotations.Component;
import org.codehaus.plexus.component.annotations.Requirement;
import org.codehaus.plexus.component.repository.exception.ComponentLookupException;

/**
 * Helper to locate a {@link TransportFactory} instance.
 *
 * @version $Rev: 601529 $ $Date: 2007-12-05 22:13:06 +0100 (Wed, 05 Dec 2007) $
 */
@Component(role = TransportFactoryLocator.class)
public class DefaultTransportFactoryLocator<T extends TransportFactory> implements TransportFactoryLocator<T> {

    @Requirement
    private PlexusContainer container;

    public PlexusContainer getContainer() {
        return container;
    }

    public void setContainer(final PlexusContainer container) {
        this.container = container;
    }

    public T locate(final URI location) throws InvalidLocationException, LookupException {
        assert location != null;

        String scheme = location.getScheme();

        if (scheme == null) {
            throw new InvalidLocationException(location);
        }

        // noinspection unchecked
        try {
            return (T) container.lookup(TransportFactory.class, scheme);
        } catch (ComponentLookupException e) {
            throw new LookupException(scheme, e);
        }
    }

}